@@ -231,7 +231,7 @@ eel_mime_add_application (const char *mime_type,
 	application_dir = get_user_dir ("applications");
 
 	/* Get a filename */
-	basename = g_strdup_printf ("%s.desktop", name);
+	basename = g_strdup_printf ("%s-usercreated.desktop", name);
 	filename = g_build_filename (application_dir, basename, NULL);
 
 	i = 1;
@@ -239,7 +239,7 @@ eel_mime_add_application (const char *mime_type,
 		g_free (basename);
 		g_free (filename);
 		
-		basename = g_strdup_printf ("%s%d.desktop", name, i);
+		basename = g_strdup_printf ("%s-usercreated-%d.desktop", name, i);
 		filename = g_build_filename (application_dir, basename, NULL);
 		
 		i++;
@@ -584,6 +584,7 @@ open_temp_cache_file (const char *dir, char **filename, GError **error)
               g_set_error (error, G_FILE_ERROR,
                            g_file_error_from_errno (errno),
                            "%s", g_strerror (errno));
+	      *filename = NULL;
               break;
             }
         }
