@@ -132,10 +132,6 @@ eel_open_with_dialog_finalize (GObject *object)
 static void
 eel_open_with_dialog_destroy (GtkObject *object)
 {
-	EelOpenWithDialog *dialog;
-
-	dialog = EEL_OPEN_WITH_DIALOG (object);
-
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
@@ -178,7 +174,6 @@ check_application (EelOpenWithDialog *dialog)
 	if (error) {
 		eel_show_error_dialog (_("Could not run application"),
 				       error->message,
-				       _("Could not run application"),
 				       GTK_WINDOW (dialog));
 		g_error_free (error);
 		retval = FALSE;
@@ -194,7 +189,6 @@ check_application (EelOpenWithDialog *dialog)
 
 		eel_show_error_dialog (_("Could not find application"),
 				       error_message,
-				       _("Could not find application"),
 				       GTK_WINDOW (dialog));
 		g_free (error_message);
 		retval = FALSE;
@@ -225,7 +219,6 @@ get_app_name (EelOpenWithDialog *dialog)
 	if (error) {
 		eel_show_error_dialog (_("Could not run application"),
 				       error->message,
-				       _("Could not run application"),
 				       GTK_WINDOW (dialog));
 		g_error_free (error);
 
@@ -287,12 +280,12 @@ add_or_find_application (EelOpenWithDialog *dialog)
 		} else {
 			app = NULL;
 		}
+		g_free (app_name);
 	}
 
 	if (!app) {
 		eel_show_error_dialog (_("Could not add application"),
 				       _("Could not add application to the application database"),
-				       _("Could not add application"),
 				       GTK_WINDOW (dialog));
 	}
 
@@ -964,6 +957,7 @@ set_uri_and_mime_type (EelOpenWithDialog *dialog,
 		dialog->details->mime_type =
 			g_strdup_printf ("application/x-extension-%s",
 					 extension);
+		/* the %s here is a file extension */
 		dialog->details->mime_description =
 			g_strdup_printf (_("%s document"), extension);
 		dialog->details->new_glob = g_strdup_printf ("*.%s",
